.. ADIOS2 documentation master file, created by
   sphinx-quickstart on Wed Jan  3 14:46:50 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ADIOS 2: The Adaptable Input/Output System version 2
====================================================

Funded by the `Exascale Computing Project (ECP) <https://www.exascaleproject.org/>`_, U.S. Department of Energy

.. toctree::
   :caption: Introduction

   introduction/whatsnew
   introduction/introduction


.. toctree::
   :caption: Setting Up

   setting_up/setting_up


.. toctree::
   :caption: Basics

   components/components
   engines/virtual_engines
   engines/engines
   operators/operators
   api_full/api_full
   api_high/api_high
   api_python/api_python

.. toctree::
   :caption: Advanced Topics
   
   advanced/aggregation
   advanced/memory_management
   advanced/gpu_aware
   advanced/query
   advanced/plugins
   advanced/campaign_management
   advanced/ecp_hardware

.. toctree::
   :caption: Tutorials

   tutorials/overview
   tutorials/downloadAndBuild
   tutorials/basicTutorials

.. toctree::
   :caption: Ecosystem Tools

   ecosystem/h5vol
   ecosystem/utilities
   ecosystem/visualization

.. toctree::
   :caption: Additional Information

   faq/faq
   advice/advice


* :ref:`search`
